summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJon TURNEY <jon.turney@dronecode.org.uk>2010-10-15 20:21:03 +0100
committerJon TURNEY <jon.turney@dronecode.org.uk>2010-10-15 20:25:19 +0100
commitb1f2a6eaac8177d838ddb4fb671dc4a8f95fe765 (patch)
tree84a5c19cc1352fec6b784c04e6d350bf2a8203fe
parent0ec3b6bf3b42d15806ddf01115968f877aee254a (diff)
Use 'current' and 'previous' rather than 'results' and 'results.prev' for clarity
-rwxr-xr-xglean-test.sh18
-rwxr-xr-xglean-wrapper4
2 files changed, 11 insertions, 11 deletions
diff --git a/glean-wrapper b/glean-wrapper
index d30d74e..c48fc6b 100755
--- a/glean-wrapper
+++ b/glean-wrapper
@@ -1,5 +1,5 @@
#!/bin/sh
glxinfo | grep -E "OpenGL [[:alpha:]]* string" >/tmp/glean.log
glxinfo | grep -E "direct" >>/tmp/glean.log
-echo glean -r results -o --quick >>/tmp/glean.log
-$JHBUILD_CHECKOUTROOT/glean/bin/glean -r results -o --quick >>/tmp/glean.log 2>&1
+echo glean -r current -o --quick >>/tmp/glean.log
+$JHBUILD_CHECKOUTROOT/glean/bin/glean -r current -o --quick >>/tmp/glean.log 2>&1
diff --git a/glean-test.sh b/glean-test.sh
index 3da633a..e344911 100755
--- a/glean-test.sh
+++ b/glean-test.sh
@@ -1,12 +1,12 @@
#!/bin/sh
-# move previous glean results to results.prev
-rm -f results.prev
-mv results results.prev
+# move previous glean results from current to previous
+rm -rf previous
+mv current previous
# start xserver and run glean against it, capturing output to /tmp/glean.log
echo >/tmp/glean.log
-xinit `pwd`/glean-wrapper -- :99 -multiwindow >/tmp/xint.log 2>&1
+xinit `pwd`/glean-wrapper -- :99 -multiwindow >/tmp/xinit.log 2>&1
cat /tmp/glean.log
# crudely summarize pass/fail statistics
@@ -15,13 +15,13 @@ FAIL=`grep -c "FAIL " /tmp/glean.log`
echo "PASS: $PASS FAIL: $FAIL"
# compare with previous statistics
-PREV_PASS=`cat .glean.pass`
-PREV_FAIL=`cat .glean.fail`
+PREV_PASS=`cat .glean.pass || echo 0`
+PREV_FAIL=`cat .glean.fail || echo 0`
EXITCODE=0
-if [ $PASS -lt $PREV_PASS ] || [ $FAIL -lt $PREV_FAIL ] ; then
+if [ $PASS -lt $PREV_PASS ] || [ $FAIL -gt $PREV_FAIL ] ; then
# report an error
- echo "Error: results worse than previous run PASS: $PREV_PASS FAIL: $PREV_FAIL"
+ echo "Error: current worse than previous PASS: $PREV_PASS FAIL: $PREV_FAIL"
EXITCODE=1
else
# record pass/fail counts for checking next time
@@ -30,6 +30,6 @@ else
fi
# use glean compare mode to report differences
-glean -c results.prev results
+$JHBUILD_CHECKOUTROOT/glean/bin/glean -c previous current
exit $EXITCODE